django-model-revisioning
========================

Add history to your models - migrations compatible!

.. image:: https://readthedocs.org/projects/django-model-revisioning/badge/?version=latest
   :target: https://django-model-revisioning.readthedocs.io/
   :alt: Documentation Status
.. image:: https://travis-ci.org/valberg/django-model-revisioning.svg?branch=master
   :target: https://travis-ci.org/valberg/django-model-revisioning
   :alt: Build Status
.. image:: https://codecov.io/gh/valberg/django-model-revisioning/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/valberg/django-model-revisioning
   :alt: Code Coverage

Supported versions
------------------

- Python 3.6, 3.7, (3.8 soon)
- Django 2.2.x, 3.0.x

Current state
-------------

django-model-revisioning is currently not production ready - we need more tests for that!

You can install the pre-release from PyPI though using::

    $ pip install django-model-revisioning==0.0.1-alpha
